Black Leaf – Microperc Oil Bong with Showerhead Diffusor - Grasscity.com | Online Headshop
Description: <h4>Black Leaf – Microperc Oil Bong with Showerhead Diffusor</h4> <p>Made from the finest quality borosilicate glass this oil rig by Black Leaf is especially designed for smoking concentrates and oils. This miniature oil bong features a built-in showerhe
Keywords: Bongs, bong, waterpipes, glass pipes, glass pipe bong, herb grinders, grasscity, headshop, rolling accessories, smoking accessories, water pipes, rolling papers, rolling paper, herbal highs, smart shop, color changing glass

http://www.grasscity.com/int_en/black-leaf-microperc-oil-bong-with-showerhead-diffusor.html 17061 Black Leaf – Microperc Oil Bong with Showerhead Diffusor 41.30 USD InStock /Bongs and Waterpipes /Bongs and Waterpipes/Glass Bongs/Mini Glass Bongs /Bongs and Waterpipes/Glass Bongs /New Items /Bongs and Waterpipes/Glass Bongs/Without Carb Hole /Brands/Black Leaf /Brands/Black Leaf /Black Leaf Glass Bongs <h4>Black Leaf – Microperc Oil Bong with Showerhead Diffusor</h4> <p>Made from the finest quality borosilicate glass this oil rig by Black Leaf is especially designed for smoking concentrates and oils. This miniature oil bong features a built-in showerhead diffuser that breaks up the smoke into finer particles, which cools down the smoke for a silky smooth hit packed with flavor. It only measures 20 cm (7.9 inches) in length, but don’t be fooled by its size, it still has a big impact!</p> <p>The main chamber, with black and gold Black Leaf “Microperc” logo, narrows down into a much thinner tube that is equipped with a comfortable flared mouthpiece. The Microperc Oil Bong by Black Leaf, with 10mm male joint, comes as a complete set up with a 10mm borosilicate glass concentrate nail and a custom made 10mm female vapor dome with a colored handle for easy lifting. The nail must be heated on top; otherwise the grinding can break in case the nail expands from the heat. </p> <p>The Microperc is available with the mouthpiece, showerhead diffusor, rim of the foot and the handle on the vapor dome colored in six different shades: black, white, light green, amber, pink and blue. Choose the color of your preference when you order.</p> 59.00 Black Leaf 2014-11-12 1 1 https://st.grscty.com/media/catalog/product/cache/2/image/115x/9df78eab33525d08d6e5fb8d27136e95/g/p/gpc_015-35.jpg
Black Leaf – Microperc Oil Bong with Showerhead Diffusor - Black
Move your mouse over image or click to enlarge

#### More Views

## Black Leaf – Microperc Oil Bong with Showerhead Diffusor

List Price: $59.00

Our Price: $41.30

You save: $17.70

Qty:

- Tell a Friend |
- Add to Wishlist
- | Add to Compare

* Required Fields

*choose color

### Overview

Small yet powerful oil rig by Black Leaf!

- Quality borosilicate glass
- Built-in showerhead diffusor
- Black and Gold "Microperc" logo on main chamber
- Flared mouthpiece
- 10mm male joint
- 10mm female vapor dome with colored handle
- Comes complete with 10mm glass concentrate nail
- Choice of 6 colors

Attention: The nail must be heated on top; otherwise the grinding can break in case the nail expands from the heat!

- Manufacturer: Black Leaf
- color: clear with colored details
- Height: 20 cm / 7.9 inches
- Glass Thickness: 3.2 mm
- Joint Size: 10 mm

- Product Description

- #### Black Leaf – Microperc Oil Bong with Showerhead Diffusor

  Made from the finest quality borosilicate glass this oil rig by Black Leaf is especially designed for smoking concentrates and oils. This miniature oil bong features a built-in showerhead diffuser that breaks up the smoke into finer particles, which cools down the smoke for a silky smooth hit packed with flavor. It only measures 20 cm (7.9 inches) in length, but don’t be fooled by its size, it still has a big impact!

  The main chamber, with black and gold Black Leaf “Microperc” logo, narrows down into a much thinner tube that is equipped with a comfortable flared mouthpiece. The Microperc Oil Bong by Black Leaf, with 10mm male joint, comes as a complete set up with a 10mm borosilicate glass concentrate nail and a custom made 10mm female vapor dome with a colored handle for easy lifting. The nail must be heated on top; otherwise the grinding can break in case the nail expands from the heat.

  The Microperc is available with the mouthpiece, showerhead diffusor, rim of the foot and the handle on the vapor dome colored in six different shades: black, white, light green, amber, pink and blue. Choose the color of your preference when you order.

"Black Leaf – Microperc Oil Bong with Showerhead Diffusor" Tags

Add Your Tags:

Use spaces to separate tags. Use single quotes (') for phrases.

Grasscity
Search site:
Advanced Search
Welcome to Grasscity International Website (change)

- Grasscity International Website
- Grasscity UK Website
- Grasscity US Website
- Grasscity Europe Website

- My Account
- My Cart
- Checkout
- Log In

English (change)

- English
- Spanish

US Dollar - USD (change)

- US Dollar - USD
- Argentine Peso - ARS
- Australian Dollar - AUD
- Brazilian Real - BRL
- British Pound Sterling - GBP
- Canadian Dollar - CAD
- Chilean Peso - CLP
- Chinese Yuan Renminbi - CNY
- Euro - EUR
- Hong Kong Dollar - HKD
- Icelandic Króna - ISK
- Israeli New Sheqel - ILS
- Japanese Yen - JPY
- Mexican Peso - MXN
- New Taiwan Dollar - TWD
- Russian Ruble - RUB
- South African Rand - ZAR
- South Korean Won - KRW
- Thai Baht - THB
- Turkish Lira - TRY
- Ukrainian Hryvnia - UAH

- Grasscity Shop
- Grasscity Forums
- Affilliates
- Support

Please wait...

{{var product.name}} added to cart
Continue shopping View cart & checkout
You just removed {{var product.name}}from your cart
Continue shopping View cart & checkout